package SOAP::Lite::Simple::DotNet;

use strict;
use Carp;

use base qw(SOAP::XML::Client::DotNet);

1;

__END__


=head1 NAME

SOAP::Lite::Simple::DotNet - depreciated for SOAP::XML::Client::DotNet

=head1 DESCRIPTION

This package has been depreciated - please use
SOAP::XML::Client::DotNet instead.

=head1 AUTHOR

Leo Lapworth <LLAP@cuckoo.org>

=head1 COPYRIGHT

(c) 2005 Leo Lapworth

This library is free software, you can use it under the same 
terms as perl itself.

=head1 SEE ALSO

  <SOAP::XML::Client> 

=cut

