package SOAP::Lite::Simple::Real;

use strict;
use Carp;

use base qw(SOAP::XML::Client::Generic);

1;
__END__

=head1 NAME

SOAP::Lite::Simple::Real - depreciated for SOAP::XML::Client::Generic

=head1 DESCRIPTION

This package has been depreciated - please use SOAP::XML::Client::Generic
instead.

=head1 AUTHOR

Leo Lapworth <LLAP@cuckoo.org>

=head1 COPYRIGHT

(c) 2005 Leo Lapworth

This library is free software, you can use it under the same 
terms as perl itself.

=head1 SEE ALSO

  <SOAP::XML::Client>

=cut
